# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmPipelineTrigger(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'description': 'str',
        'edges': 'OrmPipelineTriggerEdges',
        'enabled': 'bool',
        'id': 'int',
        'kind': 'str',
        'name': 'str',
        'pipeline_id': 'int',
        'spec': 'dict[str, object]',
        'token': 'str'
    }

    attribute_map = {
        'description': 'description',
        'edges': 'edges',
        'enabled': 'enabled',
        'id': 'id',
        'kind': 'kind',
        'name': 'name',
        'pipeline_id': 'pipeline_id',
        'spec': 'spec',
        'token': 'token'
    }

    def __init__(self, description=None, edges=None, enabled=None, id=None, kind=None, name=None, pipeline_id=None, spec=None, token=None, local_vars_configuration=None):  # noqa: E501
        """OrmPipelineTrigger - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._description = None
        self._edges = None
        self._enabled = None
        self._id = None
        self._kind = None
        self._name = None
        self._pipeline_id = None
        self._spec = None
        self._token = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if edges is not None:
            self.edges = edges
        if enabled is not None:
            self.enabled = enabled
        if id is not None:
            self.id = id
        if kind is not None:
            self.kind = kind
        if name is not None:
            self.name = name
        if pipeline_id is not None:
            self.pipeline_id = pipeline_id
        if spec is not None:
            self.spec = spec
        if token is not None:
            self.token = token

    @property
    def description(self):
        """Gets the description of this OrmPipelineTrigger.  # noqa: E501


        :return: The description of this OrmPipelineTrigger.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this OrmPipelineTrigger.


        :param description: The description of this OrmPipelineTrigger.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def edges(self):
        """Gets the edges of this OrmPipelineTrigger.  # noqa: E501


        :return: The edges of this OrmPipelineTrigger.  # noqa: E501
        :rtype: OrmPipelineTriggerEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmPipelineTrigger.


        :param edges: The edges of this OrmPipelineTrigger.  # noqa: E501
        :type edges: OrmPipelineTriggerEdges
        """

        self._edges = edges

    @property
    def enabled(self):
        """Gets the enabled of this OrmPipelineTrigger.  # noqa: E501


        :return: The enabled of this OrmPipelineTrigger.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this OrmPipelineTrigger.


        :param enabled: The enabled of this OrmPipelineTrigger.  # noqa: E501
        :type enabled: bool
        """

        self._enabled = enabled

    @property
    def id(self):
        """Gets the id of this OrmPipelineTrigger.  # noqa: E501


        :return: The id of this OrmPipelineTrigger.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmPipelineTrigger.


        :param id: The id of this OrmPipelineTrigger.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def kind(self):
        """Gets the kind of this OrmPipelineTrigger.  # noqa: E501


        :return: The kind of this OrmPipelineTrigger.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this OrmPipelineTrigger.


        :param kind: The kind of this OrmPipelineTrigger.  # noqa: E501
        :type kind: str
        """

        self._kind = kind

    @property
    def name(self):
        """Gets the name of this OrmPipelineTrigger.  # noqa: E501


        :return: The name of this OrmPipelineTrigger.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrmPipelineTrigger.


        :param name: The name of this OrmPipelineTrigger.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def pipeline_id(self):
        """Gets the pipeline_id of this OrmPipelineTrigger.  # noqa: E501


        :return: The pipeline_id of this OrmPipelineTrigger.  # noqa: E501
        :rtype: int
        """
        return self._pipeline_id

    @pipeline_id.setter
    def pipeline_id(self, pipeline_id):
        """Sets the pipeline_id of this OrmPipelineTrigger.


        :param pipeline_id: The pipeline_id of this OrmPipelineTrigger.  # noqa: E501
        :type pipeline_id: int
        """

        self._pipeline_id = pipeline_id

    @property
    def spec(self):
        """Gets the spec of this OrmPipelineTrigger.  # noqa: E501


        :return: The spec of this OrmPipelineTrigger.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this OrmPipelineTrigger.


        :param spec: The spec of this OrmPipelineTrigger.  # noqa: E501
        :type spec: dict[str, object]
        """

        self._spec = spec

    @property
    def token(self):
        """Gets the token of this OrmPipelineTrigger.  # noqa: E501


        :return: The token of this OrmPipelineTrigger.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this OrmPipelineTrigger.


        :param token: The token of this OrmPipelineTrigger.  # noqa: E501
        :type token: str
        """

        self._token = token

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmPipelineTrigger):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmPipelineTrigger):
            return True

        return self.to_dict() != other.to_dict()
