# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmVolumeEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'artifacts': 'list[OrmArtifact]',
        'locator_origin': 'OrmArtifact',
        'models': 'list[OrmModel]',
        'organization': 'OrmOrganization',
        'pipeline': 'OrmPipeline',
        'run_exec': 'OrmRunExecution',
        'storage': 'OrmStorage'
    }

    attribute_map = {
        'artifacts': 'artifacts',
        'locator_origin': 'locator_origin',
        'models': 'models',
        'organization': 'organization',
        'pipeline': 'pipeline',
        'run_exec': 'run_exec',
        'storage': 'storage'
    }

    def __init__(self, artifacts=None, locator_origin=None, models=None, organization=None, pipeline=None, run_exec=None, storage=None, local_vars_configuration=None):  # noqa: E501
        """OrmVolumeEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._artifacts = None
        self._locator_origin = None
        self._models = None
        self._organization = None
        self._pipeline = None
        self._run_exec = None
        self._storage = None
        self.discriminator = None

        if artifacts is not None:
            self.artifacts = artifacts
        if locator_origin is not None:
            self.locator_origin = locator_origin
        if models is not None:
            self.models = models
        if organization is not None:
            self.organization = organization
        if pipeline is not None:
            self.pipeline = pipeline
        if run_exec is not None:
            self.run_exec = run_exec
        if storage is not None:
            self.storage = storage

    @property
    def artifacts(self):
        """Gets the artifacts of this OrmVolumeEdges.  # noqa: E501


        :return: The artifacts of this OrmVolumeEdges.  # noqa: E501
        :rtype: list[OrmArtifact]
        """
        return self._artifacts

    @artifacts.setter
    def artifacts(self, artifacts):
        """Sets the artifacts of this OrmVolumeEdges.


        :param artifacts: The artifacts of this OrmVolumeEdges.  # noqa: E501
        :type artifacts: list[OrmArtifact]
        """

        self._artifacts = artifacts

    @property
    def locator_origin(self):
        """Gets the locator_origin of this OrmVolumeEdges.  # noqa: E501


        :return: The locator_origin of this OrmVolumeEdges.  # noqa: E501
        :rtype: OrmArtifact
        """
        return self._locator_origin

    @locator_origin.setter
    def locator_origin(self, locator_origin):
        """Sets the locator_origin of this OrmVolumeEdges.


        :param locator_origin: The locator_origin of this OrmVolumeEdges.  # noqa: E501
        :type locator_origin: OrmArtifact
        """

        self._locator_origin = locator_origin

    @property
    def models(self):
        """Gets the models of this OrmVolumeEdges.  # noqa: E501


        :return: The models of this OrmVolumeEdges.  # noqa: E501
        :rtype: list[OrmModel]
        """
        return self._models

    @models.setter
    def models(self, models):
        """Sets the models of this OrmVolumeEdges.


        :param models: The models of this OrmVolumeEdges.  # noqa: E501
        :type models: list[OrmModel]
        """

        self._models = models

    @property
    def organization(self):
        """Gets the organization of this OrmVolumeEdges.  # noqa: E501


        :return: The organization of this OrmVolumeEdges.  # noqa: E501
        :rtype: OrmOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this OrmVolumeEdges.


        :param organization: The organization of this OrmVolumeEdges.  # noqa: E501
        :type organization: OrmOrganization
        """

        self._organization = organization

    @property
    def pipeline(self):
        """Gets the pipeline of this OrmVolumeEdges.  # noqa: E501


        :return: The pipeline of this OrmVolumeEdges.  # noqa: E501
        :rtype: OrmPipeline
        """
        return self._pipeline

    @pipeline.setter
    def pipeline(self, pipeline):
        """Sets the pipeline of this OrmVolumeEdges.


        :param pipeline: The pipeline of this OrmVolumeEdges.  # noqa: E501
        :type pipeline: OrmPipeline
        """

        self._pipeline = pipeline

    @property
    def run_exec(self):
        """Gets the run_exec of this OrmVolumeEdges.  # noqa: E501


        :return: The run_exec of this OrmVolumeEdges.  # noqa: E501
        :rtype: OrmRunExecution
        """
        return self._run_exec

    @run_exec.setter
    def run_exec(self, run_exec):
        """Sets the run_exec of this OrmVolumeEdges.


        :param run_exec: The run_exec of this OrmVolumeEdges.  # noqa: E501
        :type run_exec: OrmRunExecution
        """

        self._run_exec = run_exec

    @property
    def storage(self):
        """Gets the storage of this OrmVolumeEdges.  # noqa: E501


        :return: The storage of this OrmVolumeEdges.  # noqa: E501
        :rtype: OrmStorage
        """
        return self._storage

    @storage.setter
    def storage(self, storage):
        """Sets the storage of this OrmVolumeEdges.


        :param storage: The storage of this OrmVolumeEdges.  # noqa: E501
        :type storage: OrmStorage
        """

        self._storage = storage

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmVolumeEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmVolumeEdges):
            return True

        return self.to_dict() != other.to_dict()
